"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _TaskStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TaskStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TaskStatus.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _TaskStatus.ValueType  # 0
    PENDING: _TaskStatus.ValueType  # 1
    RUNNING: _TaskStatus.ValueType  # 2
    SUCCESS: _TaskStatus.ValueType  # 3
    FAILED: _TaskStatus.ValueType  # 4

class TaskStatus(_TaskStatus, metaclass=_TaskStatusEnumTypeWrapper): ...

UNKNOWN: TaskStatus.ValueType  # 0
PENDING: TaskStatus.ValueType  # 1
RUNNING: TaskStatus.ValueType  # 2
SUCCESS: TaskStatus.ValueType  # 3
FAILED: TaskStatus.ValueType  # 4
global___TaskStatus = TaskStatus

class TaskResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOG_FIELD_NUMBER: builtins.int
    log: builtins.bytes
    """Will be set if task failed, otherwise may be empty."""
    def __init__(
        self,
        *,
        log: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["log", b"log"]) -> None: ...

global___TaskResult = TaskResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Output(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXIT_CODE_FIELD_NUMBER: builtins.int
    EXEC_ERROR_FIELD_NUMBER: builtins.int
    STDOUT_BLOB_ID_FIELD_NUMBER: builtins.int
    STDERR_BLOB_ID_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    START_TIMESTAMP_NS_FIELD_NUMBER: builtins.int
    DURATION_NS_FIELD_NUMBER: builtins.int
    FILES_FIELD_NUMBER: builtins.int
    exit_code: builtins.int
    """Exit code of wrapped process. -1 if process failed to execute."""
    exec_error: builtins.str
    """Internal error when trying to execute wrapped process."""
    stdout_blob_id: builtins.str
    stderr_blob_id: builtins.str
    version: builtins.str
    """Wrapper version."""
    start_timestamp_ns: builtins.int
    """Timestamp when the process began executing, in ns."""
    duration_ns: builtins.int
    """Total execution duration of the process, in ns."""
    @property
    def files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OutputFile]: ...
    def __init__(
        self,
        *,
        exit_code: builtins.int = ...,
        exec_error: builtins.str = ...,
        stdout_blob_id: builtins.str = ...,
        stderr_blob_id: builtins.str = ...,
        version: builtins.str = ...,
        start_timestamp_ns: builtins.int = ...,
        duration_ns: builtins.int = ...,
        files: collections.abc.Iterable[global___OutputFile] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration_ns", b"duration_ns", "exec_error", b"exec_error", "exit_code", b"exit_code", "files", b"files", "start_timestamp_ns", b"start_timestamp_ns", "stderr_blob_id", b"stderr_blob_id", "stdout_blob_id", b"stdout_blob_id", "version", b"version"]) -> None: ...

global___Output = Output

class OutputFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CONTENT_BLOB_ID_FIELD_NUMBER: builtins.int
    name: builtins.str
    content_blob_id: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        content_blob_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content_blob_id", b"content_blob_id", "name", b"name"]) -> None: ...

global___OutputFile = OutputFile



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import prodvana.proto.prodvana.events.events_manager_pb2

class EventsManagerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    GetEvents: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.events.events_manager_pb2.GetEventsReq,
        prodvana.proto.prodvana.events.events_manager_pb2.GetEventsResp,
    ]

class EventsManagerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetEvents(
        self,
        request: prodvana.proto.prodvana.events.events_manager_pb2.GetEventsReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.events.events_manager_pb2.GetEventsResp: ...

def add_EventsManagerServicer_to_server(servicer: EventsManagerServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import prodvana.proto.prodvana.common_config.meta_pb2
import prodvana.proto.prodvana.convergence.convergence_mode_pb2
import prodvana.proto.prodvana.object.meta_pb2
import prodvana.proto.prodvana.service.service_config_pb2
import prodvana.proto.prodvana.service.user_metadata_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ServiceInstanceProtectionAttachment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROTECTION_FIELD_NUMBER: builtins.int
    ATTACHMENT_FIELD_NUMBER: builtins.int
    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    ATTACHMENT_ID_FIELD_NUMBER: builtins.int
    protection: builtins.str
    attachment: builtins.str
    desired_state_id: builtins.str
    attachment_id: builtins.str
    def __init__(
        self,
        *,
        protection: builtins.str = ...,
        attachment: builtins.str = ...,
        desired_state_id: builtins.str = ...,
        attachment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["attachment", b"attachment", "attachment_id", b"attachment_id", "desired_state_id", b"desired_state_id", "protection", b"protection"]) -> None: ...

global___ServiceInstanceProtectionAttachment = ServiceInstanceProtectionAttachment

class ExternalAddr(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ExternalAddr._Type.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: ExternalAddr._Type.ValueType  # 0
        AUTO: ExternalAddr._Type.ValueType  # 1
        EXTERNAL: ExternalAddr._Type.ValueType  # 2
        RAW_IP: ExternalAddr._Type.ValueType  # 3
        """RAW_* are generated by the underlying infrastructure, independent of Prodvana"""
        RAW_HOSTNAME: ExternalAddr._Type.ValueType  # 4

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    UNKNOWN: ExternalAddr.Type.ValueType  # 0
    AUTO: ExternalAddr.Type.ValueType  # 1
    EXTERNAL: ExternalAddr.Type.ValueType  # 2
    RAW_IP: ExternalAddr.Type.ValueType  # 3
    """RAW_* are generated by the underlying infrastructure, independent of Prodvana"""
    RAW_HOSTNAME: ExternalAddr.Type.ValueType  # 4

    ADDR_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    addr: builtins.str
    type: global___ExternalAddr.Type.ValueType
    def __init__(
        self,
        *,
        addr: builtins.str = ...,
        type: global___ExternalAddr.Type.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["addr", b"addr", "type", b"type"]) -> None: ...

global___ExternalAddr = ExternalAddr

class ServiceState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONVERGENCE_MODE_FIELD_NUMBER: builtins.int
    convergence_mode: prodvana.proto.prodvana.convergence.convergence_mode_pb2.ConvergenceMode.ValueType
    def __init__(
        self,
        *,
        convergence_mode: prodvana.proto.prodvana.convergence.convergence_mode_pb2.ConvergenceMode.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["convergence_mode", b"convergence_mode"]) -> None: ...

global___ServiceState = ServiceState

class Service(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    META_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    USER_METADATA_FIELD_NUMBER: builtins.int
    @property
    def meta(self) -> prodvana.proto.prodvana.object.meta_pb2.ObjectMeta: ...
    @property
    def config(self) -> prodvana.proto.prodvana.service.service_config_pb2.ServiceConfig: ...
    @property
    def state(self) -> global___ServiceState: ...
    @property
    def user_metadata(self) -> prodvana.proto.prodvana.service.user_metadata_pb2.ServiceUserMetadata: ...
    def __init__(
        self,
        *,
        meta: prodvana.proto.prodvana.object.meta_pb2.ObjectMeta | None = ...,
        config: prodvana.proto.prodvana.service.service_config_pb2.ServiceConfig | None = ...,
        state: global___ServiceState | None = ...,
        user_metadata: prodvana.proto.prodvana.service.user_metadata_pb2.ServiceUserMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config", "meta", b"meta", "state", b"state", "user_metadata", b"user_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "meta", b"meta", "state", b"state", "user_metadata", b"user_metadata"]) -> None: ...

global___Service = Service

class ServiceInstanceState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTERNAL_ADDRS_FIELD_NUMBER: builtins.int
    PROTECTION_ATTACHMENTS_FIELD_NUMBER: builtins.int
    @property
    def external_addrs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ExternalAddr]: ...
    @property
    def protection_attachments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceInstanceProtectionAttachment]: ...
    def __init__(
        self,
        *,
        external_addrs: collections.abc.Iterable[global___ExternalAddr] | None = ...,
        protection_attachments: collections.abc.Iterable[global___ServiceInstanceProtectionAttachment] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["external_addrs", b"external_addrs", "protection_attachments", b"protection_attachments"]) -> None: ...

global___ServiceInstanceState = ServiceInstanceState

class ServiceInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    META_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    @property
    def meta(self) -> prodvana.proto.prodvana.common_config.meta_pb2.ServiceInstanceObjectMeta: ...
    @property
    def config(self) -> prodvana.proto.prodvana.service.service_config_pb2.CompiledServiceInstanceConfig:
        """will be empty if never pushed"""
    @property
    def state(self) -> global___ServiceInstanceState: ...
    def __init__(
        self,
        *,
        meta: prodvana.proto.prodvana.common_config.meta_pb2.ServiceInstanceObjectMeta | None = ...,
        config: prodvana.proto.prodvana.service.service_config_pb2.CompiledServiceInstanceConfig | None = ...,
        state: global___ServiceInstanceState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config", "meta", b"meta", "state", b"state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "meta", b"meta", "state", b"state"]) -> None: ...

global___ServiceInstance = ServiceInstance



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.common_config.links_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ServiceUserMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    LINKS_FIELD_NUMBER: builtins.int
    FOLLOW_REPOSITORY_FIELD_NUMBER: builtins.int
    description: builtins.str
    @property
    def links(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.links_pb2.Link]: ...
    @property
    def follow_repository(self) -> global___FollowContainerRepositorySettings: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        links: collections.abc.Iterable[prodvana.proto.prodvana.common_config.links_pb2.Link] | None = ...,
        follow_repository: global___FollowContainerRepositorySettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["follow_repository", b"follow_repository"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "follow_repository", b"follow_repository", "links", b"links"]) -> None: ...

global___ServiceUserMetadata = ServiceUserMetadata

class FollowContainerRepositorySettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled"]) -> None: ...

global___FollowContainerRepositorySettings = FollowContainerRepositorySettings



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from prodvana.proto.prodvana.delivery_extension import manager_pb2 as prodvana_dot_delivery__extension_dot_manager__pb2


class DeliveryExtensionManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ConfigureDeliveryExtension = channel.unary_unary(
                '/prodvana.delivery_extension.DeliveryExtensionManager/ConfigureDeliveryExtension',
                request_serializer=prodvana_dot_delivery__extension_dot_manager__pb2.ConfigureDeliveryExtensionReq.SerializeToString,
                response_deserializer=prodvana_dot_delivery__extension_dot_manager__pb2.ConfigureDeliveryExtensionResp.FromString,
                )
        self.ValidateConfigureDeliveryExtension = channel.unary_unary(
                '/prodvana.delivery_extension.DeliveryExtensionManager/ValidateConfigureDeliveryExtension',
                request_serializer=prodvana_dot_delivery__extension_dot_manager__pb2.ConfigureDeliveryExtensionReq.SerializeToString,
                response_deserializer=prodvana_dot_delivery__extension_dot_manager__pb2.ValidateConfigureDeliveryExtensionResp.FromString,
                )
        self.ListDeliveryExtensions = channel.unary_unary(
                '/prodvana.delivery_extension.DeliveryExtensionManager/ListDeliveryExtensions',
                request_serializer=prodvana_dot_delivery__extension_dot_manager__pb2.ListDeliveryExtensionsReq.SerializeToString,
                response_deserializer=prodvana_dot_delivery__extension_dot_manager__pb2.ListDeliveryExtensionsResp.FromString,
                )
        self.GetDeliveryExtension = channel.unary_unary(
                '/prodvana.delivery_extension.DeliveryExtensionManager/GetDeliveryExtension',
                request_serializer=prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionReq.SerializeToString,
                response_deserializer=prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionResp.FromString,
                )
        self.GetDeliveryExtensionConfig = channel.unary_unary(
                '/prodvana.delivery_extension.DeliveryExtensionManager/GetDeliveryExtensionConfig',
                request_serializer=prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionConfigReq.SerializeToString,
                response_deserializer=prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionConfigResp.FromString,
                )
        self.GetDeliveryExtensionInstanceConfig = channel.unary_unary(
                '/prodvana.delivery_extension.DeliveryExtensionManager/GetDeliveryExtensionInstanceConfig',
                request_serializer=prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionInstanceConfigReq.SerializeToString,
                response_deserializer=prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionInstanceConfigResp.FromString,
                )


class DeliveryExtensionManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ConfigureDeliveryExtension(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateConfigureDeliveryExtension(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDeliveryExtensions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeliveryExtension(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeliveryExtensionConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeliveryExtensionInstanceConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DeliveryExtensionManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ConfigureDeliveryExtension': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureDeliveryExtension,
                    request_deserializer=prodvana_dot_delivery__extension_dot_manager__pb2.ConfigureDeliveryExtensionReq.FromString,
                    response_serializer=prodvana_dot_delivery__extension_dot_manager__pb2.ConfigureDeliveryExtensionResp.SerializeToString,
            ),
            'ValidateConfigureDeliveryExtension': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateConfigureDeliveryExtension,
                    request_deserializer=prodvana_dot_delivery__extension_dot_manager__pb2.ConfigureDeliveryExtensionReq.FromString,
                    response_serializer=prodvana_dot_delivery__extension_dot_manager__pb2.ValidateConfigureDeliveryExtensionResp.SerializeToString,
            ),
            'ListDeliveryExtensions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDeliveryExtensions,
                    request_deserializer=prodvana_dot_delivery__extension_dot_manager__pb2.ListDeliveryExtensionsReq.FromString,
                    response_serializer=prodvana_dot_delivery__extension_dot_manager__pb2.ListDeliveryExtensionsResp.SerializeToString,
            ),
            'GetDeliveryExtension': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeliveryExtension,
                    request_deserializer=prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionReq.FromString,
                    response_serializer=prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionResp.SerializeToString,
            ),
            'GetDeliveryExtensionConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeliveryExtensionConfig,
                    request_deserializer=prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionConfigReq.FromString,
                    response_serializer=prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionConfigResp.SerializeToString,
            ),
            'GetDeliveryExtensionInstanceConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeliveryExtensionInstanceConfig,
                    request_deserializer=prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionInstanceConfigReq.FromString,
                    response_serializer=prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionInstanceConfigResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prodvana.delivery_extension.DeliveryExtensionManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DeliveryExtensionManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ConfigureDeliveryExtension(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.delivery_extension.DeliveryExtensionManager/ConfigureDeliveryExtension',
            prodvana_dot_delivery__extension_dot_manager__pb2.ConfigureDeliveryExtensionReq.SerializeToString,
            prodvana_dot_delivery__extension_dot_manager__pb2.ConfigureDeliveryExtensionResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateConfigureDeliveryExtension(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.delivery_extension.DeliveryExtensionManager/ValidateConfigureDeliveryExtension',
            prodvana_dot_delivery__extension_dot_manager__pb2.ConfigureDeliveryExtensionReq.SerializeToString,
            prodvana_dot_delivery__extension_dot_manager__pb2.ValidateConfigureDeliveryExtensionResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDeliveryExtensions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.delivery_extension.DeliveryExtensionManager/ListDeliveryExtensions',
            prodvana_dot_delivery__extension_dot_manager__pb2.ListDeliveryExtensionsReq.SerializeToString,
            prodvana_dot_delivery__extension_dot_manager__pb2.ListDeliveryExtensionsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeliveryExtension(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.delivery_extension.DeliveryExtensionManager/GetDeliveryExtension',
            prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionReq.SerializeToString,
            prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeliveryExtensionConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.delivery_extension.DeliveryExtensionManager/GetDeliveryExtensionConfig',
            prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionConfigReq.SerializeToString,
            prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionConfigResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeliveryExtensionInstanceConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.delivery_extension.DeliveryExtensionManager/GetDeliveryExtensionInstanceConfig',
            prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionInstanceConfigReq.SerializeToString,
            prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionInstanceConfigResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/protection/attachments.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.protection import protection_reference_pb2 as prodvana_dot_protection_dot_protection__reference__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%prodvana/protection/attachments.proto\x12\x13prodvana.protection\x1a.prodvana/protection/protection_reference.proto\x1a\x17validate/validate.proto\"\xe5\x01\n\x1aProtectionAttachmentConfig\x12:\n\x04name\x18\x01 \x01(\tB,\xfa\x42)r\'\x10\x00\x18?2!^[a-z]?([a-z0-9-]*[a-z0-9]){0,1}$\x12?\n\x03ref\x18\x02 \x01(\x0b\x32(.prodvana.protection.ProtectionReferenceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12J\n\tlifecycle\x18\x03 \x03(\x0b\x32(.prodvana.protection.ProtectionLifecycleB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01*Y\n\x0e\x41ttachmentType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x13\n\x0fRELEASE_CHANNEL\x10\x01\x12\x14\n\x10SERVICE_INSTANCE\x10\x02\x12\x0f\n\x0b\x43ONVERGENCE\x10\x03\x42OZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/protectionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.protection.attachments_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/protection'
  _PROTECTIONATTACHMENTCONFIG.fields_by_name['name']._options = None
  _PROTECTIONATTACHMENTCONFIG.fields_by_name['name']._serialized_options = b'\372B)r\'\020\000\030?2!^[a-z]?([a-z0-9-]*[a-z0-9]){0,1}$'
  _PROTECTIONATTACHMENTCONFIG.fields_by_name['ref']._options = None
  _PROTECTIONATTACHMENTCONFIG.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _PROTECTIONATTACHMENTCONFIG.fields_by_name['lifecycle']._options = None
  _PROTECTIONATTACHMENTCONFIG.fields_by_name['lifecycle']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _globals['_ATTACHMENTTYPE']._serialized_start=367
  _globals['_ATTACHMENTTYPE']._serialized_end=456
  _globals['_PROTECTIONATTACHMENTCONFIG']._serialized_start=136
  _globals['_PROTECTIONATTACHMENTCONFIG']._serialized_end=365
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.common_config.env_pb2
import prodvana.proto.prodvana.pipelines.pipelines_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PerReleaseChannelCapabilityConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    INLINED_FIELD_NUMBER: builtins.int
    REF_FIELD_NUMBER: builtins.int
    release_channel: builtins.str
    @property
    def inlined(self) -> global___CapabilityInstanceConfig:
        """either inline capability config definition, or reference a CapabilityInstanceDefinition
        on the top level application object
        """
    @property
    def ref(self) -> global___CapabilityInstanceRef: ...
    def __init__(
        self,
        *,
        release_channel: builtins.str = ...,
        inlined: global___CapabilityInstanceConfig | None = ...,
        ref: global___CapabilityInstanceRef | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["definition_oneof", b"definition_oneof", "inlined", b"inlined", "ref", b"ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["definition_oneof", b"definition_oneof", "inlined", b"inlined", "ref", b"ref", "release_channel", b"release_channel"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["definition_oneof", b"definition_oneof"]) -> typing_extensions.Literal["inlined", "ref"] | None: ...

global___PerReleaseChannelCapabilityConfig = PerReleaseChannelCapabilityConfig

class CapabilityConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PER_RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def per_release_channel(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PerReleaseChannelCapabilityConfig]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        per_release_channel: collections.abc.Iterable[global___PerReleaseChannelCapabilityConfig] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "per_release_channel", b"per_release_channel"]) -> None: ...

global___CapabilityConfig = CapabilityConfig

class CapabilityInstanceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    PRE_PUSH_TASKS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """omit if inlined"""
    @property
    def env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]:
        """env vars to inject"""
    @property
    def pre_push_tasks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.pipelines.pipelines_pb2.Task]:
        """Tasks to inject in the pipeline, before the push of the service instance depending on this capability
        Custom tasks will automatically have env vars from `env` above injected.
        When multiple service instances reference the same capability instance, the tasks are deduped and injected
        before the push of the first service instance in the pipeline.
        """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
        pre_push_tasks: collections.abc.Iterable[prodvana.proto.prodvana.pipelines.pipelines_pb2.Task] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["env", b"env", "name", b"name", "pre_push_tasks", b"pre_push_tasks"]) -> None: ...

global___CapabilityInstanceConfig = CapabilityInstanceConfig

class CapabilityInstanceRef(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___CapabilityInstanceRef = CapabilityInstanceRef



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import prodvana.proto.prodvana.object.meta_pb2
import prodvana.proto.prodvana.release.object_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class RecordReleaseReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    PENDING_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> prodvana.proto.prodvana.release.object_pb2.ReleaseConfig: ...
    pending: builtins.bool
    """If true, create release with pending status that is meant to be updated later to either success or failure.
    By default, releases are created with status SUCCEEDED.
    """
    def __init__(
        self,
        *,
        config: prodvana.proto.prodvana.release.object_pb2.ReleaseConfig | None = ...,
        pending: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "pending", b"pending"]) -> None: ...

global___RecordReleaseReq = RecordReleaseReq

class RecordReleaseResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    META_FIELD_NUMBER: builtins.int
    @property
    def meta(self) -> prodvana.proto.prodvana.object.meta_pb2.ObjectMeta: ...
    def __init__(
        self,
        *,
        meta: prodvana.proto.prodvana.object.meta_pb2.ObjectMeta | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["meta", b"meta"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["meta", b"meta"]) -> None: ...

global___RecordReleaseResp = RecordReleaseResp

class UpdateReleaseStatusReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    release_id: builtins.str
    status: prodvana.proto.prodvana.release.object_pb2.ReleaseStatus.ValueType
    def __init__(
        self,
        *,
        release_id: builtins.str = ...,
        status: prodvana.proto.prodvana.release.object_pb2.ReleaseStatus.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["release_id", b"release_id", "status", b"status"]) -> None: ...

global___UpdateReleaseStatusReq = UpdateReleaseStatusReq

class UpdateReleaseStatusResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: prodvana.proto.prodvana.release.object_pb2.ReleaseStatus.ValueType
    def __init__(
        self,
        *,
        status: prodvana.proto.prodvana.release.object_pb2.ReleaseStatus.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status"]) -> None: ...

global___UpdateReleaseStatusResp = UpdateReleaseStatusResp

class ReleaseFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICES_FIELD_NUMBER: builtins.int
    RELEASE_CHANNELS_FIELD_NUMBER: builtins.int
    APPLICATION_FIELD_NUMBER: builtins.int
    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    @property
    def services(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """filters to releases for join(join(services, OR), join(release_channels, OR), AND)"""
    @property
    def release_channels(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    application: builtins.str
    """if set, the filters on services and release channels above will be limited to this app.
    Otherwise, there is no app filter (so e.g. release_channels=['staging'] will select
    staging release channels across all apps.)
    """
    desired_state_id: builtins.str
    """desired_state_id filter is AND'ed with everything else in the same filter object"""
    def __init__(
        self,
        *,
        services: collections.abc.Iterable[builtins.str] | None = ...,
        release_channels: collections.abc.Iterable[builtins.str] | None = ...,
        application: builtins.str = ...,
        desired_state_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "desired_state_id", b"desired_state_id", "release_channels", b"release_channels", "services", b"services"]) -> None: ...

global___ReleaseFilter = ReleaseFilter

class ListReleasesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILTERS_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    STARTING_RELEASE_ID_FIELD_NUMBER: builtins.int
    ENDING_RELEASE_ID_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    @property
    def filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReleaseFilter]:
        """filters for listing releases. Multiple filters are OR'ed together."""
    @property
    def filter(self) -> global___ReleaseFilter:
        """escape hatch to support openAPI, which cannot handle repeated list of messages on GET requests. This is joined to the filters list with an OR."""
    starting_release_id: builtins.str
    """newer release, inclusive"""
    ending_release_id: builtins.str
    """older release, exclusive"""
    page_token: builtins.str
    page_size: builtins.int
    def __init__(
        self,
        *,
        filters: collections.abc.Iterable[global___ReleaseFilter] | None = ...,
        filter: global___ReleaseFilter | None = ...,
        starting_release_id: builtins.str = ...,
        ending_release_id: builtins.str = ...,
        page_token: builtins.str = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["filter", b"filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ending_release_id", b"ending_release_id", "filter", b"filter", "filters", b"filters", "page_size", b"page_size", "page_token", b"page_token", "starting_release_id", b"starting_release_id"]) -> None: ...

global___ListReleasesReq = ListReleasesReq

class ListReleasesResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def releases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.release.object_pb2.Release]: ...
    next_page_token: builtins.str
    def __init__(
        self,
        *,
        releases: collections.abc.Iterable[prodvana.proto.prodvana.release.object_pb2.Release] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_page_token", b"next_page_token", "releases", b"releases"]) -> None: ...

global___ListReleasesResp = ListReleasesResp

class ReleaseRef(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_ID_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    release_id: builtins.str
    @property
    def config(self) -> prodvana.proto.prodvana.release.object_pb2.ReleaseConfig: ...
    def __init__(
        self,
        *,
        release_id: builtins.str = ...,
        config: prodvana.proto.prodvana.release.object_pb2.ReleaseConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config", "ref", b"ref", "release_id", b"release_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "ref", b"ref", "release_id", b"release_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["ref", b"ref"]) -> typing_extensions.Literal["release_id", "config"] | None: ...

global___ReleaseRef = ReleaseRef

class CompareReleaseReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NEW_RELEASE_FIELD_NUMBER: builtins.int
    PREV_RELEASE_FIELD_NUMBER: builtins.int
    @property
    def new_release(self) -> global___ReleaseRef: ...
    @property
    def prev_release(self) -> global___ReleaseRef: ...
    def __init__(
        self,
        *,
        new_release: global___ReleaseRef | None = ...,
        prev_release: global___ReleaseRef | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["new_release", b"new_release", "prev_release", b"prev_release"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["new_release", b"new_release", "prev_release", b"prev_release"]) -> None: ...

global___CompareReleaseReq = CompareReleaseReq

class CompareReleaseResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPARISON_FIELD_NUMBER: builtins.int
    @property
    def comparison(self) -> prodvana.proto.prodvana.release.object_pb2.ReleaseComparison: ...
    def __init__(
        self,
        *,
        comparison: prodvana.proto.prodvana.release.object_pb2.ReleaseComparison | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["comparison", b"comparison"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["comparison", b"comparison"]) -> None: ...

global___CompareReleaseResp = CompareReleaseResp

class PreviewReleaseReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    PREV_RELEASE_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> prodvana.proto.prodvana.release.object_pb2.ReleaseConfig: ...
    @property
    def prev_release(self) -> global___ReleaseRef:
        """omit to use latest release from the same app/service/release channel"""
    def __init__(
        self,
        *,
        config: prodvana.proto.prodvana.release.object_pb2.ReleaseConfig | None = ...,
        prev_release: global___ReleaseRef | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config", "prev_release", b"prev_release"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "prev_release", b"prev_release"]) -> None: ...

global___PreviewReleaseReq = PreviewReleaseReq

class PreviewReleaseResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_FIELD_NUMBER: builtins.int
    @property
    def release(self) -> prodvana.proto.prodvana.release.object_pb2.Release: ...
    def __init__(
        self,
        *,
        release: prodvana.proto.prodvana.release.object_pb2.Release | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release", b"release"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["release", b"release"]) -> None: ...

global___PreviewReleaseResp = PreviewReleaseResp

class GetLatestReleasesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILTERS_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    @property
    def filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReleaseFilter]:
        """filters for listing releases. Multiple filters are OR'ed together."""
    @property
    def filter(self) -> global___ReleaseFilter:
        """escape hatch to support openAPI, which cannot handle repeated list of messages on GET requests. This is joined to the filters list with an OR."""
    status: prodvana.proto.prodvana.release.object_pb2.ReleaseStatus.ValueType
    """if set, only return releases with this status"""
    page_token: builtins.str
    page_size: builtins.int
    def __init__(
        self,
        *,
        filters: collections.abc.Iterable[global___ReleaseFilter] | None = ...,
        filter: global___ReleaseFilter | None = ...,
        status: prodvana.proto.prodvana.release.object_pb2.ReleaseStatus.ValueType = ...,
        page_token: builtins.str = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["filter", b"filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["filter", b"filter", "filters", b"filters", "page_size", b"page_size", "page_token", b"page_token", "status", b"status"]) -> None: ...

global___GetLatestReleasesReq = GetLatestReleasesReq

class GetLatestReleasesResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def releases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.release.object_pb2.Release]: ...
    next_page_token: builtins.str
    def __init__(
        self,
        *,
        releases: collections.abc.Iterable[prodvana.proto.prodvana.release.object_pb2.Release] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_page_token", b"next_page_token", "releases", b"releases"]) -> None: ...

global___GetLatestReleasesResp = GetLatestReleasesResp

class ReleaseServiceInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    release_channel: builtins.str
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
        release_channel: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "release_channel", b"release_channel", "service", b"service"]) -> None: ...

global___ReleaseServiceInstance = ReleaseServiceInstance

class CheckCommitInReleaseReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_ID_FIELD_NUMBER: builtins.int
    RELEASE_SERVICE_INSTANCE_FIELD_NUMBER: builtins.int
    REPOSITORY_FIELD_NUMBER: builtins.int
    COMMIT_FIELD_NUMBER: builtins.int
    release_id: builtins.str
    @property
    def release_service_instance(self) -> global___ReleaseServiceInstance:
        """will pick latest release"""
    repository: builtins.str
    commit: builtins.str
    def __init__(
        self,
        *,
        release_id: builtins.str = ...,
        release_service_instance: global___ReleaseServiceInstance | None = ...,
        repository: builtins.str = ...,
        commit: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release_id", b"release_id", "release_oneof", b"release_oneof", "release_service_instance", b"release_service_instance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["commit", b"commit", "release_id", b"release_id", "release_oneof", b"release_oneof", "release_service_instance", b"release_service_instance", "repository", b"repository"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["release_oneof", b"release_oneof"]) -> typing_extensions.Literal["release_id", "release_service_instance"] | None: ...

global___CheckCommitInReleaseReq = CheckCommitInReleaseReq

class CheckCommitInReleaseResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Result:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ResultEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CheckCommitInReleaseResp._Result.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: CheckCommitInReleaseResp._Result.ValueType  # 0
        INCLUDED: CheckCommitInReleaseResp._Result.ValueType  # 1
        NO_RELATION: CheckCommitInReleaseResp._Result.ValueType  # 2
        NOT_INCLUDED: CheckCommitInReleaseResp._Result.ValueType  # 3

    class Result(_Result, metaclass=_ResultEnumTypeWrapper): ...
    UNKNOWN: CheckCommitInReleaseResp.Result.ValueType  # 0
    INCLUDED: CheckCommitInReleaseResp.Result.ValueType  # 1
    NO_RELATION: CheckCommitInReleaseResp.Result.ValueType  # 2
    NOT_INCLUDED: CheckCommitInReleaseResp.Result.ValueType  # 3

    RESULT_FIELD_NUMBER: builtins.int
    result: global___CheckCommitInReleaseResp.Result.ValueType
    def __init__(
        self,
        *,
        result: global___CheckCommitInReleaseResp.Result.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["result", b"result"]) -> None: ...

global___CheckCommitInReleaseResp = CheckCommitInReleaseResp



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import prodvana.proto.prodvana.version.source_metadata_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ObjectType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ObjectTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ObjectType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _ObjectType.ValueType  # 0
    RUNTIME: _ObjectType.ValueType  # 1
    APPLICATION: _ObjectType.ValueType  # 2
    SERVICE: _ObjectType.ValueType  # 3
    RELEASE_CHANNEL: _ObjectType.ValueType  # 4
    PROTECTION: _ObjectType.ValueType  # 5
    RELEASE: _ObjectType.ValueType  # 6

class ObjectType(_ObjectType, metaclass=_ObjectTypeEnumTypeWrapper): ...

UNKNOWN: ObjectType.ValueType  # 0
RUNTIME: ObjectType.ValueType  # 1
APPLICATION: ObjectType.ValueType  # 2
SERVICE: ObjectType.ValueType  # 3
RELEASE_CHANNEL: ObjectType.ValueType  # 4
PROTECTION: ObjectType.ValueType  # 5
RELEASE: ObjectType.ValueType  # 6
global___ObjectType = ObjectType

class ObjectMeta(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    CONFIG_VERSION_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    SOURCE_METADATA_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    version: builtins.str
    config_version: builtins.str
    """only set for objects who has configurations with parametrization support. At the time of this writing, only services."""
    source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
    @property
    def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
    type: global___ObjectType.ValueType
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        version: builtins.str = ...,
        config_version: builtins.str = ...,
        source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
        source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
        type: global___ObjectType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["source_metadata", b"source_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_version", b"config_version", "id", b"id", "name", b"name", "source", b"source", "source_metadata", b"source_metadata", "type", b"type", "version", b"version"]) -> None: ...

global___ObjectMeta = ObjectMeta



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/events/types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.pvn_wrapper import output_pb2 as prodvana_dot_pvn__wrapper_dot_output__pb2
from prodvana.proto.prodvana.desired_state.model import desired_state_pb2 as prodvana_dot_desired__state_dot_model_dot_desired__state__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bprodvana/events/types.proto\x12\x0fprodvana.events\x1a!prodvana/pvn_wrapper/output.proto\x1a\x30prodvana/desired_state/model/desired_state.proto\x1a\x19google/protobuf/any.proto\"\xd0\x01\n\x14SetDesiredStateEvent\x12\x34\n\x02id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x18\n\x10\x64\x65sired_state_id\x18\x03 \x01(\t\x12\x1d\n\x15root_desired_state_id\x18\x04 \x01(\t\x12\x34\n\x07\x64\x65sired\x18\x02 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x13\n\x0bis_rollback\x18\x05 \x01(\x08\"\xc3\x03\n\x13SetTargetStateEvent\x12\x34\n\x02id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x18\n\x10\x64\x65sired_state_id\x18\x08 \x01(\t\x12\x1d\n\x15root_desired_state_id\x18\t \x01(\t\x12\x33\n\x06target\x18\x02 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x34\n\x07\x64\x65sired\x18\x03 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x34\n\x07\x63urrent\x18\x04 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x18\n\x10is_auto_rollback\x18\x05 \x01(\x08\x12\x34\n\x06status\x18\x06 \x01(\x0e\x32$.prodvana.desired_state.model.Status\x12L\n\x13status_explanations\x18\x07 \x03(\x0b\x32/.prodvana.desired_state.model.StatusExplanation\"\xac\x03\n\x15\x41pplyTargetStateEvent\x12\x34\n\x02id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x18\n\x10\x64\x65sired_state_id\x18\x06 \x01(\t\x12\x1d\n\x15root_desired_state_id\x18\x07 \x01(\t\x12\x33\n\x06target\x18\x02 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x34\n\x07\x63urrent\x18\x03 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x18\n\x10is_auto_rollback\x18\x04 \x01(\x08\x12\x42\n\x06result\x18\x05 \x01(\x0e\x32\x32.prodvana.events.ApplyTargetStateEvent.ApplyResult\x12\r\n\x05\x65rror\x18\x08 \x01(\t\"L\n\x0b\x41pplyResult\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tSUCCEEDED\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\x12\x15\n\x11RETRIABLE_FAILURE\x10\x03\"\xe9\x01\n\x10ProgramExitEvent\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0b\n\x03pod\x18\x02 \x01(\t\x12\x0f\n\x07program\x18\x03 \x01(\t\x12\x15\n\rrestart_count\x18\x04 \x01(\x05\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x15\n\rkilled_reason\x18\t \x01(\t\x12\x11\n\texit_code\x18\x06 \x01(\x05\x12\x0e\n\x06signal\x18\x07 \x01(\x05\x12\x37\n\x11structured_output\x18\n \x01(\x0b\x32\x1c.prodvana.pvn_wrapper.OutputJ\x04\x08\x08\x10\tR\x04logs\"S\n\x15\x44\x65liveryProgressEvent\x12:\n\x05state\x18\x01 \x01(\x0b\x32+.prodvana.desired_state.model.DeliveryState\"w\n\x1c\x44\x65liveryManualPromotionEvent\x12:\n\x05state\x18\x01 \x01(\x0b\x32+.prodvana.desired_state.model.DeliveryState\x12\r\n\x05stage\x18\x02 \x01(\x03\x12\x0c\n\x04\x66ull\x18\x03 \x01(\x08\"h\n\x13ManualApprovalEvent\x12\x42\n\x06status\x18\x01 \x01(\x0e\x32\x32.prodvana.desired_state.model.ManualApprovalStatus\x12\r\n\x05topic\x18\x02 \x01(\t\"\\\n\x18\x43ustomTaskExecutionEvent\x12\x12\n\nsuccessful\x18\x01 \x01(\x08\x12\x10\n\x08\x61ttempts\x18\x02 \x01(\x05\x12\x0e\n\x06reason\x18\x03 \x01(\tJ\x04\x08\x04\x10\x05R\x04logs\"K\n\rRuntimeObject\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\"\xe4\x02\n\x12RuntimeUpdateEvent\x12\x41\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x31.prodvana.events.RuntimeUpdateEvent.RuntimeAction\x12.\n\x06object\x18\x02 \x01(\x0b\x32\x1e.prodvana.events.RuntimeObject\x12\x41\n\x06status\x18\x03 \x01(\x0e\x32\x31.prodvana.events.RuntimeUpdateEvent.RuntimeStatus\"D\n\rRuntimeAction\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x14\n\x10\x43REATE_OR_UPDATE\x10\x01\x12\x10\n\x0cWAIT_HEALTHY\x10\x02\"R\n\rRuntimeStatus\x12\x1a\n\x16RUNTIME_STATUS_UNKNOWN\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0b\n\x07SUCCESS\x10\x02\x12\x0b\n\x07\x46\x41ILURE\x10\x03\"\xab\x04\n\x1d\x44\x65siredStateStatusChangeEvent\x12\x34\n\x02id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x18\n\x10\x64\x65sired_state_id\x18\x02 \x01(\t\x12\x1d\n\x15root_desired_state_id\x18\x03 \x01(\t\x12\x38\n\nold_status\x18\x04 \x01(\x0e\x32$.prodvana.desired_state.model.Status\x12\x38\n\nnew_status\x18\x05 \x01(\x0e\x32$.prodvana.desired_state.model.Status\x12\x34\n\x07\x64\x65sired\x18\x06 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x33\n\x06target\x18\x07 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x36\n\told_state\x18\x08 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x36\n\tnew_state\x18\t \x01(\x0b\x32#.prodvana.desired_state.model.State\x12L\n\x13status_explanations\x18\n \x03(\x0b\x32/.prodvana.desired_state.model.StatusExplanation\"\xc6\x04\n\x18KeyDeliveryDecisionEvent\x12\x34\n\x02id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x18\n\x10\x64\x65sired_state_id\x18\x02 \x01(\t\x12\x1d\n\x15root_desired_state_id\x18\x03 \x01(\t\x12\x44\n\x08\x64\x65\x63ision\x18\x04 \x01(\x0e\x32\x32.prodvana.events.KeyDeliveryDecisionEvent.Decision\x12\x13\n\x0b\x65xplanation\x18\x05 \x01(\t\x12\x34\n\x06status\x18\x06 \x01(\x0e\x32$.prodvana.desired_state.model.Status\x12\x34\n\x07\x64\x65sired\x18\x07 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x33\n\x06target\x18\x08 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x34\n\x07\x63urrent\x18\t \x01(\x0b\x32#.prodvana.desired_state.model.State\x12L\n\x13status_explanations\x18\n \x03(\x0b\x32/.prodvana.desired_state.model.StatusExplanation\";\n\x08\x44\x65\x63ision\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x16\n\x12ROLLBACK_INITIATED\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\"\xe2\x01\n\x0cRpcCallEvent\x12\x30\n\x04type\x18\x01 \x01(\x0e\x32\".prodvana.events.RpcCallEvent.Type\x12\x13\n\x0brpc_service\x18\x02 \x01(\t\x12\x12\n\nrpc_method\x18\x03 \x01(\t\x12%\n\x07request\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\x12&\n\x08response\x18\x05 \x01(\x0b\x32\x14.google.protobuf.Any\"(\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04READ\x10\x01\x12\t\n\x05WRITE\x10\x02\"-\n\x11\x41pplicationHandle\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"i\n\x14ReleaseChannelHandle\x12\x37\n\x0b\x61pplication\x18\x01 \x01(\x0b\x32\".prodvana.events.ApplicationHandle\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\"\xa2\x01\n\rServiceHandle\x12\x37\n\x0b\x61pplication\x18\x01 \x01(\x0b\x32\".prodvana.events.ApplicationHandle\x12>\n\x0frelease_channel\x18\x02 \x01(\x0b\x32%.prodvana.events.ReleaseChannelHandle\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\")\n\rRuntimeHandle\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\",\n\x10ProtectionHandle\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"\xa8\x03\n\x15PermissionDeniedEvent\x12=\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32-.prodvana.events.PermissionDeniedEvent.Action\x12\x39\n\x0b\x61pplication\x18\x02 \x01(\x0b\x32\".prodvana.events.ApplicationHandleH\x00\x12@\n\x0frelease_channel\x18\x03 \x01(\x0b\x32%.prodvana.events.ReleaseChannelHandleH\x00\x12\x31\n\x07service\x18\x04 \x01(\x0b\x32\x1e.prodvana.events.ServiceHandleH\x00\x12\x31\n\x07runtime\x18\x05 \x01(\x0b\x32\x1e.prodvana.events.RuntimeHandleH\x00\x12\x37\n\nprotection\x18\x06 \x01(\x0b\x32!.prodvana.events.ProtectionHandleH\x00\"*\n\x06\x41\x63tion\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04READ\x10\x01\x12\t\n\x05WRITE\x10\x02\x42\x08\n\x06target\"\xd2\x02\n\x12ObjectCreatedEvent\x12\x16\n\x0e\x63onfig_version\x18\x01 \x01(\t\x12\x39\n\x0b\x61pplication\x18\x02 \x01(\x0b\x32\".prodvana.events.ApplicationHandleH\x00\x12@\n\x0frelease_channel\x18\x03 \x01(\x0b\x32%.prodvana.events.ReleaseChannelHandleH\x00\x12\x31\n\x07service\x18\x04 \x01(\x0b\x32\x1e.prodvana.events.ServiceHandleH\x00\x12\x31\n\x07runtime\x18\x05 \x01(\x0b\x32\x1e.prodvana.events.RuntimeHandleH\x00\x12\x37\n\nprotection\x18\x06 \x01(\x0b\x32!.prodvana.events.ProtectionHandleH\x00\x42\x08\n\x06target\"\xd2\x02\n\x12ObjectDeletedEvent\x12\x16\n\x0e\x63onfig_version\x18\x01 \x01(\t\x12\x39\n\x0b\x61pplication\x18\x02 \x01(\x0b\x32\".prodvana.events.ApplicationHandleH\x00\x12@\n\x0frelease_channel\x18\x03 \x01(\x0b\x32%.prodvana.events.ReleaseChannelHandleH\x00\x12\x31\n\x07service\x18\x04 \x01(\x0b\x32\x1e.prodvana.events.ServiceHandleH\x00\x12\x31\n\x07runtime\x18\x05 \x01(\x0b\x32\x1e.prodvana.events.RuntimeHandleH\x00\x12\x37\n\nprotection\x18\x06 \x01(\x0b\x32!.prodvana.events.ProtectionHandleH\x00\x42\x08\n\x06target\"\xf3\x02\n\x13ObjectModifiedEvent\x12\x1a\n\x12old_config_version\x18\x01 \x01(\t\x12\x1a\n\x12new_config_version\x18\x02 \x01(\t\x12\x39\n\x0b\x61pplication\x18\x03 \x01(\x0b\x32\".prodvana.events.ApplicationHandleH\x00\x12@\n\x0frelease_channel\x18\x04 \x01(\x0b\x32%.prodvana.events.ReleaseChannelHandleH\x00\x12\x31\n\x07service\x18\x05 \x01(\x0b\x32\x1e.prodvana.events.ServiceHandleH\x00\x12\x31\n\x07runtime\x18\x06 \x01(\x0b\x32\x1e.prodvana.events.RuntimeHandleH\x00\x12\x37\n\nprotection\x18\x07 \x01(\x0b\x32!.prodvana.events.ProtectionHandleH\x00\x42\x08\n\x06target\"C\n\x0fKubectlCmdEvent\x12\x0f\n\x07runtime\x18\x01 \x01(\t\x12\x0c\n\x04\x61rgs\x18\x02 \x03(\t\x12\x11\n\texit_code\x18\x03 \x01(\x05\"\x87\x01\n\x12\x41uditLogDebugEvent\x12\x41\n\x07\x64\x65tails\x18\x01 \x03(\x0b\x32\x30.prodvana.events.AuditLogDebugEvent.DetailsEntry\x1a.\n\x0c\x44\x65tailsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd7\t\n\x0c\x45ventDetails\x12\x42\n\x11set_desired_state\x18\x01 \x01(\x0b\x32%.prodvana.events.SetDesiredStateEventH\x00\x12@\n\x10set_target_state\x18\x02 \x01(\x0b\x32$.prodvana.events.SetTargetStateEventH\x00\x12\x39\n\x0cprogram_exit\x18\x03 \x01(\x0b\x32!.prodvana.events.ProgramExitEventH\x00\x12\x44\n\x12\x61pply_target_state\x18\x04 \x01(\x0b\x32&.prodvana.events.ApplyTargetStateEventH\x00\x12?\n\x0fmanual_approval\x18\x06 \x01(\x0b\x32$.prodvana.events.ManualApprovalEventH\x00\x12J\n\x15\x63ustom_task_execution\x18\x07 \x01(\x0b\x32).prodvana.events.CustomTaskExecutionEventH\x00\x12=\n\x0eruntime_update\x18\x08 \x01(\x0b\x32#.prodvana.events.RuntimeUpdateEventH\x00\x12\x43\n\x11\x64\x65livery_progress\x18\t \x01(\x0b\x32&.prodvana.events.DeliveryProgressEventH\x00\x12K\n\x12\x64\x65livery_promotion\x18\n \x01(\x0b\x32-.prodvana.events.DeliveryManualPromotionEventH\x00\x12U\n\x1b\x64\x65sired_state_status_change\x18\x0b \x01(\x0b\x32..prodvana.events.DesiredStateStatusChangeEventH\x00\x12J\n\x15key_delivery_decision\x18\x0c \x01(\x0b\x32).prodvana.events.KeyDeliveryDecisionEventH\x00\x12\x31\n\x08rpc_call\x18\r \x01(\x0b\x32\x1d.prodvana.events.RpcCallEventH\x00\x12\x43\n\x11permission_denied\x18\x0e \x01(\x0b\x32&.prodvana.events.PermissionDeniedEventH\x00\x12=\n\x0eobject_created\x18\x0f \x01(\x0b\x32#.prodvana.events.ObjectCreatedEventH\x00\x12=\n\x0eobject_deleted\x18\x10 \x01(\x0b\x32#.prodvana.events.ObjectDeletedEventH\x00\x12?\n\x0fobject_modified\x18\x11 \x01(\x0b\x32$.prodvana.events.ObjectModifiedEventH\x00\x12\x37\n\x0bkubectl_cmd\x18\x12 \x01(\x0b\x32 .prodvana.events.KubectlCmdEventH\x00\x12>\n\x0f\x61udit_log_debug\x18\x13 \x01(\x0b\x32#.prodvana.events.AuditLogDebugEventH\x00\x42\t\n\x07\x64\x65tailsJ\x04\x08\x05\x10\x06*\xb2\x03\n\tEventType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x15\n\x11SET_DESIRED_STATE\x10\x01\x12\x14\n\x10SET_TARGET_STATE\x10\x02\x12\x10\n\x0cPROGRAM_EXIT\x10\x03\x12\x16\n\x12\x41PPLY_TARGET_STATE\x10\x04\x12\x13\n\x0fMANUAL_APPROVAL\x10\x06\x12\x19\n\x15\x43USTOM_TASK_EXECUTION\x10\x07\x12\x12\n\x0eRUNTIME_UPDATE\x10\x08\x12\x15\n\x11\x44\x45LIVERY_PROGRESS\x10\t\x12\x1d\n\x19\x44\x45LIVERY_MANUAL_PROMOTION\x10\n\x12\x1f\n\x1b\x44\x45SIRED_STATE_STATUS_CHANGE\x10\x0b\x12\x19\n\x15KEY_DELIVERY_DECISION\x10\x0c\x12\x0c\n\x08RPC_CALL\x10\r\x12\x14\n\x10PERMISSON_DENIED\x10\x0e\x12\x12\n\x0eOBJECT_CREATED\x10\x0f\x12\x12\n\x0eOBJECT_DELETED\x10\x10\x12\x13\n\x0fOBJECT_MODIFIED\x10\x11\x12\x0f\n\x0bKUBECTL_CMD\x10\x12\x12\x13\n\x0f\x41UDIT_LOG_DEBUG\x10\x13\"\x04\x08\x05\x10\x05\x42KZIgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/eventsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.events.types_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZIgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/events'
  _AUDITLOGDEBUGEVENT_DETAILSENTRY._options = None
  _AUDITLOGDEBUGEVENT_DETAILSENTRY._serialized_options = b'8\001'
  _globals['_EVENTTYPE']._serialized_start=7047
  _globals['_EVENTTYPE']._serialized_end=7481
  _globals['_SETDESIREDSTATEEVENT']._serialized_start=161
  _globals['_SETDESIREDSTATEEVENT']._serialized_end=369
  _globals['_SETTARGETSTATEEVENT']._serialized_start=372
  _globals['_SETTARGETSTATEEVENT']._serialized_end=823
  _globals['_APPLYTARGETSTATEEVENT']._serialized_start=826
  _globals['_APPLYTARGETSTATEEVENT']._serialized_end=1254
  _globals['_APPLYTARGETSTATEEVENT_APPLYRESULT']._serialized_start=1178
  _globals['_APPLYTARGETSTATEEVENT_APPLYRESULT']._serialized_end=1254
  _globals['_PROGRAMEXITEVENT']._serialized_start=1257
  _globals['_PROGRAMEXITEVENT']._serialized_end=1490
  _globals['_DELIVERYPROGRESSEVENT']._serialized_start=1492
  _globals['_DELIVERYPROGRESSEVENT']._serialized_end=1575
  _globals['_DELIVERYMANUALPROMOTIONEVENT']._serialized_start=1577
  _globals['_DELIVERYMANUALPROMOTIONEVENT']._serialized_end=1696
  _globals['_MANUALAPPROVALEVENT']._serialized_start=1698
  _globals['_MANUALAPPROVALEVENT']._serialized_end=1802
  _globals['_CUSTOMTASKEXECUTIONEVENT']._serialized_start=1804
  _globals['_CUSTOMTASKEXECUTIONEVENT']._serialized_end=1896
  _globals['_RUNTIMEOBJECT']._serialized_start=1898
  _globals['_RUNTIMEOBJECT']._serialized_end=1973
  _globals['_RUNTIMEUPDATEEVENT']._serialized_start=1976
  _globals['_RUNTIMEUPDATEEVENT']._serialized_end=2332
  _globals['_RUNTIMEUPDATEEVENT_RUNTIMEACTION']._serialized_start=2180
  _globals['_RUNTIMEUPDATEEVENT_RUNTIMEACTION']._serialized_end=2248
  _globals['_RUNTIMEUPDATEEVENT_RUNTIMESTATUS']._serialized_start=2250
  _globals['_RUNTIMEUPDATEEVENT_RUNTIMESTATUS']._serialized_end=2332
  _globals['_DESIREDSTATESTATUSCHANGEEVENT']._serialized_start=2335
  _globals['_DESIREDSTATESTATUSCHANGEEVENT']._serialized_end=2890
  _globals['_KEYDELIVERYDECISIONEVENT']._serialized_start=2893
  _globals['_KEYDELIVERYDECISIONEVENT']._serialized_end=3475
  _globals['_KEYDELIVERYDECISIONEVENT_DECISION']._serialized_start=3416
  _globals['_KEYDELIVERYDECISIONEVENT_DECISION']._serialized_end=3475
  _globals['_RPCCALLEVENT']._serialized_start=3478
  _globals['_RPCCALLEVENT']._serialized_end=3704
  _globals['_RPCCALLEVENT_TYPE']._serialized_start=3664
  _globals['_RPCCALLEVENT_TYPE']._serialized_end=3704
  _globals['_APPLICATIONHANDLE']._serialized_start=3706
  _globals['_APPLICATIONHANDLE']._serialized_end=3751
  _globals['_RELEASECHANNELHANDLE']._serialized_start=3753
  _globals['_RELEASECHANNELHANDLE']._serialized_end=3858
  _globals['_SERVICEHANDLE']._serialized_start=3861
  _globals['_SERVICEHANDLE']._serialized_end=4023
  _globals['_RUNTIMEHANDLE']._serialized_start=4025
  _globals['_RUNTIMEHANDLE']._serialized_end=4066
  _globals['_PROTECTIONHANDLE']._serialized_start=4068
  _globals['_PROTECTIONHANDLE']._serialized_end=4112
  _globals['_PERMISSIONDENIEDEVENT']._serialized_start=4115
  _globals['_PERMISSIONDENIEDEVENT']._serialized_end=4539
  _globals['_PERMISSIONDENIEDEVENT_ACTION']._serialized_start=4487
  _globals['_PERMISSIONDENIEDEVENT_ACTION']._serialized_end=4529
  _globals['_OBJECTCREATEDEVENT']._serialized_start=4542
  _globals['_OBJECTCREATEDEVENT']._serialized_end=4880
  _globals['_OBJECTDELETEDEVENT']._serialized_start=4883
  _globals['_OBJECTDELETEDEVENT']._serialized_end=5221
  _globals['_OBJECTMODIFIEDEVENT']._serialized_start=5224
  _globals['_OBJECTMODIFIEDEVENT']._serialized_end=5595
  _globals['_KUBECTLCMDEVENT']._serialized_start=5597
  _globals['_KUBECTLCMDEVENT']._serialized_end=5664
  _globals['_AUDITLOGDEBUGEVENT']._serialized_start=5667
  _globals['_AUDITLOGDEBUGEVENT']._serialized_end=5802
  _globals['_AUDITLOGDEBUGEVENT_DETAILSENTRY']._serialized_start=5756
  _globals['_AUDITLOGDEBUGEVENT_DETAILSENTRY']._serialized_end=5802
  _globals['_EVENTDETAILS']._serialized_start=5805
  _globals['_EVENTDETAILS']._serialized_end=7044
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class User(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    API_USER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FIRST_NAME_FIELD_NUMBER: builtins.int
    LAST_NAME_FIELD_NUMBER: builtins.int
    EMAILS_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    api_user: builtins.bool
    """indicates if this user represents an api token"""
    name: builtins.str
    """user info, all optional"""
    first_name: builtins.str
    last_name: builtins.str
    @property
    def emails(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        api_user: builtins.bool = ...,
        name: builtins.str = ...,
        first_name: builtins.str = ...,
        last_name: builtins.str = ...,
        emails: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_user", b"api_user", "emails", b"emails", "first_name", b"first_name", "last_name", b"last_name", "name", b"name", "user_id", b"user_id"]) -> None: ...

global___User = User



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import prodvana.proto.prodvana.desired_state.model.desired_state_pb2
import prodvana.proto.prodvana.pvn_wrapper.output_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _EventType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _EventTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_EventType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _EventType.ValueType  # 0
    SET_DESIRED_STATE: _EventType.ValueType  # 1
    """when a user sets a new desired state"""
    SET_TARGET_STATE: _EventType.ValueType  # 2
    """when dyanmic delivery sets a new target state as part of convergence. A desired state convergence
    involves a series of SET_TARGET_STATE event, one per each entity managed as part of convergence.
    """
    PROGRAM_EXIT: _EventType.ValueType  # 3
    APPLY_TARGET_STATE: _EventType.ValueType  # 4
    """When dynamic delivery materializes a target state to physical infrastructure as part of convergence.
    Each SET_TARGET_STATE is followed by one or more APPLY_TARGET_STATE, unless convergence is aborted.
    """
    MANUAL_APPROVAL: _EventType.ValueType  # 6
    CUSTOM_TASK_EXECUTION: _EventType.ValueType  # 7
    RUNTIME_UPDATE: _EventType.ValueType  # 8
    """generic runtime events when more specific event types are not available."""
    DELIVERY_PROGRESS: _EventType.ValueType  # 9
    DELIVERY_MANUAL_PROMOTION: _EventType.ValueType  # 10
    DESIRED_STATE_STATUS_CHANGE: _EventType.ValueType  # 11
    KEY_DELIVERY_DECISION: _EventType.ValueType  # 12
    RPC_CALL: _EventType.ValueType  # 13
    PERMISSON_DENIED: _EventType.ValueType  # 14
    OBJECT_CREATED: _EventType.ValueType  # 15
    OBJECT_DELETED: _EventType.ValueType  # 16
    OBJECT_MODIFIED: _EventType.ValueType  # 17
    KUBECTL_CMD: _EventType.ValueType  # 18
    AUDIT_LOG_DEBUG: _EventType.ValueType  # 19
    """a generic event type for submitting an audit log only event
    without creating an explicit event type for it.
    This should only be used for short lived logs. If the log will
    be around for a long time, it should be elevated to a proper event type.
    """

class EventType(_EventType, metaclass=_EventTypeEnumTypeWrapper): ...

UNKNOWN: EventType.ValueType  # 0
SET_DESIRED_STATE: EventType.ValueType  # 1
"""when a user sets a new desired state"""
SET_TARGET_STATE: EventType.ValueType  # 2
"""when dyanmic delivery sets a new target state as part of convergence. A desired state convergence
involves a series of SET_TARGET_STATE event, one per each entity managed as part of convergence.
"""
PROGRAM_EXIT: EventType.ValueType  # 3
APPLY_TARGET_STATE: EventType.ValueType  # 4
"""When dynamic delivery materializes a target state to physical infrastructure as part of convergence.
Each SET_TARGET_STATE is followed by one or more APPLY_TARGET_STATE, unless convergence is aborted.
"""
MANUAL_APPROVAL: EventType.ValueType  # 6
CUSTOM_TASK_EXECUTION: EventType.ValueType  # 7
RUNTIME_UPDATE: EventType.ValueType  # 8
"""generic runtime events when more specific event types are not available."""
DELIVERY_PROGRESS: EventType.ValueType  # 9
DELIVERY_MANUAL_PROMOTION: EventType.ValueType  # 10
DESIRED_STATE_STATUS_CHANGE: EventType.ValueType  # 11
KEY_DELIVERY_DECISION: EventType.ValueType  # 12
RPC_CALL: EventType.ValueType  # 13
PERMISSON_DENIED: EventType.ValueType  # 14
OBJECT_CREATED: EventType.ValueType  # 15
OBJECT_DELETED: EventType.ValueType  # 16
OBJECT_MODIFIED: EventType.ValueType  # 17
KUBECTL_CMD: EventType.ValueType  # 18
AUDIT_LOG_DEBUG: EventType.ValueType  # 19
"""a generic event type for submitting an audit log only event
without creating an explicit event type for it.
This should only be used for short lived logs. If the log will
be around for a long time, it should be elevated to a proper event type.
"""
global___EventType = EventType

class SetDesiredStateEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    ROOT_DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    DESIRED_FIELD_NUMBER: builtins.int
    IS_ROLLBACK_FIELD_NUMBER: builtins.int
    @property
    def id(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
    desired_state_id: builtins.str
    root_desired_state_id: builtins.str
    @property
    def desired(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    is_rollback: builtins.bool
    def __init__(
        self,
        *,
        id: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
        desired_state_id: builtins.str = ...,
        root_desired_state_id: builtins.str = ...,
        desired: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        is_rollback: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["desired", b"desired", "id", b"id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["desired", b"desired", "desired_state_id", b"desired_state_id", "id", b"id", "is_rollback", b"is_rollback", "root_desired_state_id", b"root_desired_state_id"]) -> None: ...

global___SetDesiredStateEvent = SetDesiredStateEvent

class SetTargetStateEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    ROOT_DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    DESIRED_FIELD_NUMBER: builtins.int
    CURRENT_FIELD_NUMBER: builtins.int
    IS_AUTO_ROLLBACK_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    STATUS_EXPLANATIONS_FIELD_NUMBER: builtins.int
    @property
    def id(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
    desired_state_id: builtins.str
    root_desired_state_id: builtins.str
    @property
    def target(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State:
        """state that prodvana runtime will immediately converge towards"""
    @property
    def desired(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State:
        """final desired state that this entity should eventually get to"""
    @property
    def current(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State:
        """current state for this entity before setting target state"""
    is_auto_rollback: builtins.bool
    """whether this is part of an automated rollback action"""
    status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType
    """status and explanations at the time of SetTargetState"""
    @property
    def status_explanations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.StatusExplanation]: ...
    def __init__(
        self,
        *,
        id: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
        desired_state_id: builtins.str = ...,
        root_desired_state_id: builtins.str = ...,
        target: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        desired: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        current: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        is_auto_rollback: builtins.bool = ...,
        status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType = ...,
        status_explanations: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.StatusExplanation] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["current", b"current", "desired", b"desired", "id", b"id", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["current", b"current", "desired", b"desired", "desired_state_id", b"desired_state_id", "id", b"id", "is_auto_rollback", b"is_auto_rollback", "root_desired_state_id", b"root_desired_state_id", "status", b"status", "status_explanations", b"status_explanations", "target", b"target"]) -> None: ...

global___SetTargetStateEvent = SetTargetStateEvent

class ApplyTargetStateEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ApplyResult:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ApplyResultEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ApplyTargetStateEvent._ApplyResult.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: ApplyTargetStateEvent._ApplyResult.ValueType  # 0
        SUCCEEDED: ApplyTargetStateEvent._ApplyResult.ValueType  # 1
        FAILED: ApplyTargetStateEvent._ApplyResult.ValueType  # 2
        RETRIABLE_FAILURE: ApplyTargetStateEvent._ApplyResult.ValueType  # 3

    class ApplyResult(_ApplyResult, metaclass=_ApplyResultEnumTypeWrapper): ...
    UNKNOWN: ApplyTargetStateEvent.ApplyResult.ValueType  # 0
    SUCCEEDED: ApplyTargetStateEvent.ApplyResult.ValueType  # 1
    FAILED: ApplyTargetStateEvent.ApplyResult.ValueType  # 2
    RETRIABLE_FAILURE: ApplyTargetStateEvent.ApplyResult.ValueType  # 3

    ID_FIELD_NUMBER: builtins.int
    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    ROOT_DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    CURRENT_FIELD_NUMBER: builtins.int
    IS_AUTO_ROLLBACK_FIELD_NUMBER: builtins.int
    RESULT_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    @property
    def id(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
    desired_state_id: builtins.str
    root_desired_state_id: builtins.str
    @property
    def target(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State:
        """state that prodvana runtime will immediately converge towards"""
    @property
    def current(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State:
        """current state for this entity before setting target state"""
    is_auto_rollback: builtins.bool
    """whether this is part of an automated rollback action"""
    result: global___ApplyTargetStateEvent.ApplyResult.ValueType
    error: builtins.str
    """set if result = FAILED"""
    def __init__(
        self,
        *,
        id: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
        desired_state_id: builtins.str = ...,
        root_desired_state_id: builtins.str = ...,
        target: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        current: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        is_auto_rollback: builtins.bool = ...,
        result: global___ApplyTargetStateEvent.ApplyResult.ValueType = ...,
        error: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["current", b"current", "id", b"id", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["current", b"current", "desired_state_id", b"desired_state_id", "error", b"error", "id", b"id", "is_auto_rollback", b"is_auto_rollback", "result", b"result", "root_desired_state_id", b"root_desired_state_id", "target", b"target"]) -> None: ...

global___ApplyTargetStateEvent = ApplyTargetStateEvent

class ProgramExitEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_FIELD_NUMBER: builtins.int
    POD_FIELD_NUMBER: builtins.int
    PROGRAM_FIELD_NUMBER: builtins.int
    RESTART_COUNT_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    KILLED_REASON_FIELD_NUMBER: builtins.int
    EXIT_CODE_FIELD_NUMBER: builtins.int
    SIGNAL_FIELD_NUMBER: builtins.int
    STRUCTURED_OUTPUT_FIELD_NUMBER: builtins.int
    namespace: builtins.str
    pod: builtins.str
    program: builtins.str
    """in k8s, this is container name"""
    restart_count: builtins.int
    reason: builtins.str
    """reason why process exited"""
    killed_reason: builtins.str
    """if killed, this is the reason why it was killed (best effort)"""
    exit_code: builtins.int
    """if 0, this is a successful exit."""
    signal: builtins.int
    """signal used to terminate this process, if any"""
    @property
    def structured_output(self) -> prodvana.proto.prodvana.pvn_wrapper.output_pb2.Output:
        """optional structured output, if the process exited with a schema compatible with pvn_wrapper's structured output"""
    def __init__(
        self,
        *,
        namespace: builtins.str = ...,
        pod: builtins.str = ...,
        program: builtins.str = ...,
        restart_count: builtins.int = ...,
        reason: builtins.str = ...,
        killed_reason: builtins.str = ...,
        exit_code: builtins.int = ...,
        signal: builtins.int = ...,
        structured_output: prodvana.proto.prodvana.pvn_wrapper.output_pb2.Output | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["structured_output", b"structured_output"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["exit_code", b"exit_code", "killed_reason", b"killed_reason", "namespace", b"namespace", "pod", b"pod", "program", b"program", "reason", b"reason", "restart_count", b"restart_count", "signal", b"signal", "structured_output", b"structured_output"]) -> None: ...

global___ProgramExitEvent = ProgramExitEvent

class DeliveryProgressEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATE_FIELD_NUMBER: builtins.int
    @property
    def state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.DeliveryState: ...
    def __init__(
        self,
        *,
        state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.DeliveryState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["state", b"state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["state", b"state"]) -> None: ...

global___DeliveryProgressEvent = DeliveryProgressEvent

class DeliveryManualPromotionEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATE_FIELD_NUMBER: builtins.int
    STAGE_FIELD_NUMBER: builtins.int
    FULL_FIELD_NUMBER: builtins.int
    @property
    def state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.DeliveryState: ...
    stage: builtins.int
    full: builtins.bool
    def __init__(
        self,
        *,
        state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.DeliveryState | None = ...,
        stage: builtins.int = ...,
        full: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["state", b"state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["full", b"full", "stage", b"stage", "state", b"state"]) -> None: ...

global___DeliveryManualPromotionEvent = DeliveryManualPromotionEvent

class ManualApprovalEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ManualApprovalStatus.ValueType
    """Approved/rejected?"""
    topic: builtins.str
    """Actor etc ..."""
    def __init__(
        self,
        *,
        status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ManualApprovalStatus.ValueType = ...,
        topic: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status", "topic", b"topic"]) -> None: ...

global___ManualApprovalEvent = ManualApprovalEvent

class CustomTaskExecutionEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESSFUL_FIELD_NUMBER: builtins.int
    ATTEMPTS_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    successful: builtins.bool
    attempts: builtins.int
    reason: builtins.str
    """Why did this job exit/fail?"""
    def __init__(
        self,
        *,
        successful: builtins.bool = ...,
        attempts: builtins.int = ...,
        reason: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["attempts", b"attempts", "reason", b"reason", "successful", b"successful"]) -> None: ...

global___CustomTaskExecutionEvent = CustomTaskExecutionEvent

class RuntimeObject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    name: builtins.str
    """name of object as it appears in the runtime layer"""
    kind: builtins.str
    namespace: builtins.str
    """optional, depends on if runtime has support for it"""
    url: builtins.str
    """optional, depends on if there is a unique URL to view this object."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        kind: builtins.str = ...,
        namespace: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kind", b"kind", "name", b"name", "namespace", b"namespace", "url", b"url"]) -> None: ...

global___RuntimeObject = RuntimeObject

class RuntimeUpdateEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _RuntimeAction:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RuntimeActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RuntimeUpdateEvent._RuntimeAction.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: RuntimeUpdateEvent._RuntimeAction.ValueType  # 0
        CREATE_OR_UPDATE: RuntimeUpdateEvent._RuntimeAction.ValueType  # 1
        WAIT_HEALTHY: RuntimeUpdateEvent._RuntimeAction.ValueType  # 2

    class RuntimeAction(_RuntimeAction, metaclass=_RuntimeActionEnumTypeWrapper): ...
    UNKNOWN: RuntimeUpdateEvent.RuntimeAction.ValueType  # 0
    CREATE_OR_UPDATE: RuntimeUpdateEvent.RuntimeAction.ValueType  # 1
    WAIT_HEALTHY: RuntimeUpdateEvent.RuntimeAction.ValueType  # 2

    class _RuntimeStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RuntimeStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RuntimeUpdateEvent._RuntimeStatus.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        RUNTIME_STATUS_UNKNOWN: RuntimeUpdateEvent._RuntimeStatus.ValueType  # 0
        PENDING: RuntimeUpdateEvent._RuntimeStatus.ValueType  # 1
        SUCCESS: RuntimeUpdateEvent._RuntimeStatus.ValueType  # 2
        FAILURE: RuntimeUpdateEvent._RuntimeStatus.ValueType  # 3

    class RuntimeStatus(_RuntimeStatus, metaclass=_RuntimeStatusEnumTypeWrapper): ...
    RUNTIME_STATUS_UNKNOWN: RuntimeUpdateEvent.RuntimeStatus.ValueType  # 0
    PENDING: RuntimeUpdateEvent.RuntimeStatus.ValueType  # 1
    SUCCESS: RuntimeUpdateEvent.RuntimeStatus.ValueType  # 2
    FAILURE: RuntimeUpdateEvent.RuntimeStatus.ValueType  # 3

    ACTION_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    action: global___RuntimeUpdateEvent.RuntimeAction.ValueType
    @property
    def object(self) -> global___RuntimeObject: ...
    status: global___RuntimeUpdateEvent.RuntimeStatus.ValueType
    def __init__(
        self,
        *,
        action: global___RuntimeUpdateEvent.RuntimeAction.ValueType = ...,
        object: global___RuntimeObject | None = ...,
        status: global___RuntimeUpdateEvent.RuntimeStatus.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["object", b"object"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "object", b"object", "status", b"status"]) -> None: ...

global___RuntimeUpdateEvent = RuntimeUpdateEvent

class DesiredStateStatusChangeEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    ROOT_DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    OLD_STATUS_FIELD_NUMBER: builtins.int
    NEW_STATUS_FIELD_NUMBER: builtins.int
    DESIRED_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    OLD_STATE_FIELD_NUMBER: builtins.int
    NEW_STATE_FIELD_NUMBER: builtins.int
    STATUS_EXPLANATIONS_FIELD_NUMBER: builtins.int
    @property
    def id(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
    desired_state_id: builtins.str
    root_desired_state_id: builtins.str
    old_status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType
    new_status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType
    @property
    def desired(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def target(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def old_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def new_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def status_explanations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.StatusExplanation]: ...
    def __init__(
        self,
        *,
        id: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
        desired_state_id: builtins.str = ...,
        root_desired_state_id: builtins.str = ...,
        old_status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType = ...,
        new_status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType = ...,
        desired: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        target: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        old_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        new_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        status_explanations: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.StatusExplanation] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["desired", b"desired", "id", b"id", "new_state", b"new_state", "old_state", b"old_state", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["desired", b"desired", "desired_state_id", b"desired_state_id", "id", b"id", "new_state", b"new_state", "new_status", b"new_status", "old_state", b"old_state", "old_status", b"old_status", "root_desired_state_id", b"root_desired_state_id", "status_explanations", b"status_explanations", "target", b"target"]) -> None: ...

global___DesiredStateStatusChangeEvent = DesiredStateStatusChangeEvent

class KeyDeliveryDecisionEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Decision:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _DecisionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[KeyDeliveryDecisionEvent._Decision.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: KeyDeliveryDecisionEvent._Decision.ValueType  # 0
        ROLLBACK_INITIATED: KeyDeliveryDecisionEvent._Decision.ValueType  # 1
        FAILED: KeyDeliveryDecisionEvent._Decision.ValueType  # 2

    class Decision(_Decision, metaclass=_DecisionEnumTypeWrapper): ...
    UNKNOWN: KeyDeliveryDecisionEvent.Decision.ValueType  # 0
    ROLLBACK_INITIATED: KeyDeliveryDecisionEvent.Decision.ValueType  # 1
    FAILED: KeyDeliveryDecisionEvent.Decision.ValueType  # 2

    ID_FIELD_NUMBER: builtins.int
    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    ROOT_DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    DECISION_FIELD_NUMBER: builtins.int
    EXPLANATION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DESIRED_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    CURRENT_FIELD_NUMBER: builtins.int
    STATUS_EXPLANATIONS_FIELD_NUMBER: builtins.int
    @property
    def id(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
    desired_state_id: builtins.str
    root_desired_state_id: builtins.str
    decision: global___KeyDeliveryDecisionEvent.Decision.ValueType
    explanation: builtins.str
    """optional, may not always be set. when not set, the context should be obvious from status_explanations"""
    status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType
    @property
    def desired(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def target(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def current(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def status_explanations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.StatusExplanation]: ...
    def __init__(
        self,
        *,
        id: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
        desired_state_id: builtins.str = ...,
        root_desired_state_id: builtins.str = ...,
        decision: global___KeyDeliveryDecisionEvent.Decision.ValueType = ...,
        explanation: builtins.str = ...,
        status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType = ...,
        desired: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        target: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        current: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        status_explanations: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.StatusExplanation] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["current", b"current", "desired", b"desired", "id", b"id", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["current", b"current", "decision", b"decision", "desired", b"desired", "desired_state_id", b"desired_state_id", "explanation", b"explanation", "id", b"id", "root_desired_state_id", b"root_desired_state_id", "status", b"status", "status_explanations", b"status_explanations", "target", b"target"]) -> None: ...

global___KeyDeliveryDecisionEvent = KeyDeliveryDecisionEvent

class RpcCallEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RpcCallEvent._Type.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: RpcCallEvent._Type.ValueType  # 0
        READ: RpcCallEvent._Type.ValueType  # 1
        WRITE: RpcCallEvent._Type.ValueType  # 2

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    UNKNOWN: RpcCallEvent.Type.ValueType  # 0
    READ: RpcCallEvent.Type.ValueType  # 1
    WRITE: RpcCallEvent.Type.ValueType  # 2

    TYPE_FIELD_NUMBER: builtins.int
    RPC_SERVICE_FIELD_NUMBER: builtins.int
    RPC_METHOD_FIELD_NUMBER: builtins.int
    REQUEST_FIELD_NUMBER: builtins.int
    RESPONSE_FIELD_NUMBER: builtins.int
    type: global___RpcCallEvent.Type.ValueType
    rpc_service: builtins.str
    rpc_method: builtins.str
    @property
    def request(self) -> google.protobuf.any_pb2.Any: ...
    @property
    def response(self) -> google.protobuf.any_pb2.Any: ...
    def __init__(
        self,
        *,
        type: global___RpcCallEvent.Type.ValueType = ...,
        rpc_service: builtins.str = ...,
        rpc_method: builtins.str = ...,
        request: google.protobuf.any_pb2.Any | None = ...,
        response: google.protobuf.any_pb2.Any | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["request", b"request", "response", b"response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["request", b"request", "response", b"response", "rpc_method", b"rpc_method", "rpc_service", b"rpc_service", "type", b"type"]) -> None: ...

global___RpcCallEvent = RpcCallEvent

class ApplicationHandle(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    name: builtins.str
    id: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name"]) -> None: ...

global___ApplicationHandle = ApplicationHandle

class ReleaseChannelHandle(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    @property
    def application(self) -> global___ApplicationHandle: ...
    name: builtins.str
    id: builtins.str
    def __init__(
        self,
        *,
        application: global___ApplicationHandle | None = ...,
        name: builtins.str = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["application", b"application"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "id", b"id", "name", b"name"]) -> None: ...

global___ReleaseChannelHandle = ReleaseChannelHandle

class ServiceHandle(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    @property
    def application(self) -> global___ApplicationHandle: ...
    @property
    def release_channel(self) -> global___ReleaseChannelHandle: ...
    name: builtins.str
    id: builtins.str
    def __init__(
        self,
        *,
        application: global___ApplicationHandle | None = ...,
        release_channel: global___ReleaseChannelHandle | None = ...,
        name: builtins.str = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["application", b"application", "release_channel", b"release_channel"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "id", b"id", "name", b"name", "release_channel", b"release_channel"]) -> None: ...

global___ServiceHandle = ServiceHandle

class RuntimeHandle(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    name: builtins.str
    id: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name"]) -> None: ...

global___RuntimeHandle = RuntimeHandle

class ProtectionHandle(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    name: builtins.str
    id: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name"]) -> None: ...

global___ProtectionHandle = ProtectionHandle

class PermissionDeniedEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Action:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PermissionDeniedEvent._Action.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: PermissionDeniedEvent._Action.ValueType  # 0
        READ: PermissionDeniedEvent._Action.ValueType  # 1
        WRITE: PermissionDeniedEvent._Action.ValueType  # 2

    class Action(_Action, metaclass=_ActionEnumTypeWrapper): ...
    UNKNOWN: PermissionDeniedEvent.Action.ValueType  # 0
    READ: PermissionDeniedEvent.Action.ValueType  # 1
    WRITE: PermissionDeniedEvent.Action.ValueType  # 2

    ACTION_FIELD_NUMBER: builtins.int
    APPLICATION_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    RUNTIME_FIELD_NUMBER: builtins.int
    PROTECTION_FIELD_NUMBER: builtins.int
    action: global___PermissionDeniedEvent.Action.ValueType
    @property
    def application(self) -> global___ApplicationHandle: ...
    @property
    def release_channel(self) -> global___ReleaseChannelHandle: ...
    @property
    def service(self) -> global___ServiceHandle: ...
    @property
    def runtime(self) -> global___RuntimeHandle: ...
    @property
    def protection(self) -> global___ProtectionHandle: ...
    def __init__(
        self,
        *,
        action: global___PermissionDeniedEvent.Action.ValueType = ...,
        application: global___ApplicationHandle | None = ...,
        release_channel: global___ReleaseChannelHandle | None = ...,
        service: global___ServiceHandle | None = ...,
        runtime: global___RuntimeHandle | None = ...,
        protection: global___ProtectionHandle | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["application", b"application", "protection", b"protection", "release_channel", b"release_channel", "runtime", b"runtime", "service", b"service", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "application", b"application", "protection", b"protection", "release_channel", b"release_channel", "runtime", b"runtime", "service", b"service", "target", b"target"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["target", b"target"]) -> typing_extensions.Literal["application", "release_channel", "service", "runtime", "protection"] | None: ...

global___PermissionDeniedEvent = PermissionDeniedEvent

class ObjectCreatedEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_VERSION_FIELD_NUMBER: builtins.int
    APPLICATION_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    RUNTIME_FIELD_NUMBER: builtins.int
    PROTECTION_FIELD_NUMBER: builtins.int
    config_version: builtins.str
    @property
    def application(self) -> global___ApplicationHandle: ...
    @property
    def release_channel(self) -> global___ReleaseChannelHandle: ...
    @property
    def service(self) -> global___ServiceHandle: ...
    @property
    def runtime(self) -> global___RuntimeHandle: ...
    @property
    def protection(self) -> global___ProtectionHandle: ...
    def __init__(
        self,
        *,
        config_version: builtins.str = ...,
        application: global___ApplicationHandle | None = ...,
        release_channel: global___ReleaseChannelHandle | None = ...,
        service: global___ServiceHandle | None = ...,
        runtime: global___RuntimeHandle | None = ...,
        protection: global___ProtectionHandle | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["application", b"application", "protection", b"protection", "release_channel", b"release_channel", "runtime", b"runtime", "service", b"service", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "config_version", b"config_version", "protection", b"protection", "release_channel", b"release_channel", "runtime", b"runtime", "service", b"service", "target", b"target"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["target", b"target"]) -> typing_extensions.Literal["application", "release_channel", "service", "runtime", "protection"] | None: ...

global___ObjectCreatedEvent = ObjectCreatedEvent

class ObjectDeletedEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_VERSION_FIELD_NUMBER: builtins.int
    APPLICATION_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    RUNTIME_FIELD_NUMBER: builtins.int
    PROTECTION_FIELD_NUMBER: builtins.int
    config_version: builtins.str
    @property
    def application(self) -> global___ApplicationHandle: ...
    @property
    def release_channel(self) -> global___ReleaseChannelHandle: ...
    @property
    def service(self) -> global___ServiceHandle: ...
    @property
    def runtime(self) -> global___RuntimeHandle: ...
    @property
    def protection(self) -> global___ProtectionHandle: ...
    def __init__(
        self,
        *,
        config_version: builtins.str = ...,
        application: global___ApplicationHandle | None = ...,
        release_channel: global___ReleaseChannelHandle | None = ...,
        service: global___ServiceHandle | None = ...,
        runtime: global___RuntimeHandle | None = ...,
        protection: global___ProtectionHandle | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["application", b"application", "protection", b"protection", "release_channel", b"release_channel", "runtime", b"runtime", "service", b"service", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "config_version", b"config_version", "protection", b"protection", "release_channel", b"release_channel", "runtime", b"runtime", "service", b"service", "target", b"target"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["target", b"target"]) -> typing_extensions.Literal["application", "release_channel", "service", "runtime", "protection"] | None: ...

global___ObjectDeletedEvent = ObjectDeletedEvent

class ObjectModifiedEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OLD_CONFIG_VERSION_FIELD_NUMBER: builtins.int
    NEW_CONFIG_VERSION_FIELD_NUMBER: builtins.int
    APPLICATION_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    RUNTIME_FIELD_NUMBER: builtins.int
    PROTECTION_FIELD_NUMBER: builtins.int
    old_config_version: builtins.str
    new_config_version: builtins.str
    @property
    def application(self) -> global___ApplicationHandle: ...
    @property
    def release_channel(self) -> global___ReleaseChannelHandle: ...
    @property
    def service(self) -> global___ServiceHandle: ...
    @property
    def runtime(self) -> global___RuntimeHandle: ...
    @property
    def protection(self) -> global___ProtectionHandle: ...
    def __init__(
        self,
        *,
        old_config_version: builtins.str = ...,
        new_config_version: builtins.str = ...,
        application: global___ApplicationHandle | None = ...,
        release_channel: global___ReleaseChannelHandle | None = ...,
        service: global___ServiceHandle | None = ...,
        runtime: global___RuntimeHandle | None = ...,
        protection: global___ProtectionHandle | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["application", b"application", "protection", b"protection", "release_channel", b"release_channel", "runtime", b"runtime", "service", b"service", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "new_config_version", b"new_config_version", "old_config_version", b"old_config_version", "protection", b"protection", "release_channel", b"release_channel", "runtime", b"runtime", "service", b"service", "target", b"target"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["target", b"target"]) -> typing_extensions.Literal["application", "release_channel", "service", "runtime", "protection"] | None: ...

global___ObjectModifiedEvent = ObjectModifiedEvent

class KubectlCmdEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNTIME_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    EXIT_CODE_FIELD_NUMBER: builtins.int
    runtime: builtins.str
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    exit_code: builtins.int
    def __init__(
        self,
        *,
        runtime: builtins.str = ...,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        exit_code: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["args", b"args", "exit_code", b"exit_code", "runtime", b"runtime"]) -> None: ...

global___KubectlCmdEvent = KubectlCmdEvent

class AuditLogDebugEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class DetailsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DETAILS_FIELD_NUMBER: builtins.int
    @property
    def details(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        details: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["details", b"details"]) -> None: ...

global___AuditLogDebugEvent = AuditLogDebugEvent

class EventDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SET_DESIRED_STATE_FIELD_NUMBER: builtins.int
    SET_TARGET_STATE_FIELD_NUMBER: builtins.int
    PROGRAM_EXIT_FIELD_NUMBER: builtins.int
    APPLY_TARGET_STATE_FIELD_NUMBER: builtins.int
    MANUAL_APPROVAL_FIELD_NUMBER: builtins.int
    CUSTOM_TASK_EXECUTION_FIELD_NUMBER: builtins.int
    RUNTIME_UPDATE_FIELD_NUMBER: builtins.int
    DELIVERY_PROGRESS_FIELD_NUMBER: builtins.int
    DELIVERY_PROMOTION_FIELD_NUMBER: builtins.int
    DESIRED_STATE_STATUS_CHANGE_FIELD_NUMBER: builtins.int
    KEY_DELIVERY_DECISION_FIELD_NUMBER: builtins.int
    RPC_CALL_FIELD_NUMBER: builtins.int
    PERMISSION_DENIED_FIELD_NUMBER: builtins.int
    OBJECT_CREATED_FIELD_NUMBER: builtins.int
    OBJECT_DELETED_FIELD_NUMBER: builtins.int
    OBJECT_MODIFIED_FIELD_NUMBER: builtins.int
    KUBECTL_CMD_FIELD_NUMBER: builtins.int
    AUDIT_LOG_DEBUG_FIELD_NUMBER: builtins.int
    @property
    def set_desired_state(self) -> global___SetDesiredStateEvent: ...
    @property
    def set_target_state(self) -> global___SetTargetStateEvent: ...
    @property
    def program_exit(self) -> global___ProgramExitEvent: ...
    @property
    def apply_target_state(self) -> global___ApplyTargetStateEvent: ...
    @property
    def manual_approval(self) -> global___ManualApprovalEvent: ...
    @property
    def custom_task_execution(self) -> global___CustomTaskExecutionEvent: ...
    @property
    def runtime_update(self) -> global___RuntimeUpdateEvent: ...
    @property
    def delivery_progress(self) -> global___DeliveryProgressEvent: ...
    @property
    def delivery_promotion(self) -> global___DeliveryManualPromotionEvent: ...
    @property
    def desired_state_status_change(self) -> global___DesiredStateStatusChangeEvent: ...
    @property
    def key_delivery_decision(self) -> global___KeyDeliveryDecisionEvent: ...
    @property
    def rpc_call(self) -> global___RpcCallEvent: ...
    @property
    def permission_denied(self) -> global___PermissionDeniedEvent: ...
    @property
    def object_created(self) -> global___ObjectCreatedEvent: ...
    @property
    def object_deleted(self) -> global___ObjectDeletedEvent: ...
    @property
    def object_modified(self) -> global___ObjectModifiedEvent: ...
    @property
    def kubectl_cmd(self) -> global___KubectlCmdEvent: ...
    @property
    def audit_log_debug(self) -> global___AuditLogDebugEvent: ...
    def __init__(
        self,
        *,
        set_desired_state: global___SetDesiredStateEvent | None = ...,
        set_target_state: global___SetTargetStateEvent | None = ...,
        program_exit: global___ProgramExitEvent | None = ...,
        apply_target_state: global___ApplyTargetStateEvent | None = ...,
        manual_approval: global___ManualApprovalEvent | None = ...,
        custom_task_execution: global___CustomTaskExecutionEvent | None = ...,
        runtime_update: global___RuntimeUpdateEvent | None = ...,
        delivery_progress: global___DeliveryProgressEvent | None = ...,
        delivery_promotion: global___DeliveryManualPromotionEvent | None = ...,
        desired_state_status_change: global___DesiredStateStatusChangeEvent | None = ...,
        key_delivery_decision: global___KeyDeliveryDecisionEvent | None = ...,
        rpc_call: global___RpcCallEvent | None = ...,
        permission_denied: global___PermissionDeniedEvent | None = ...,
        object_created: global___ObjectCreatedEvent | None = ...,
        object_deleted: global___ObjectDeletedEvent | None = ...,
        object_modified: global___ObjectModifiedEvent | None = ...,
        kubectl_cmd: global___KubectlCmdEvent | None = ...,
        audit_log_debug: global___AuditLogDebugEvent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["apply_target_state", b"apply_target_state", "audit_log_debug", b"audit_log_debug", "custom_task_execution", b"custom_task_execution", "delivery_progress", b"delivery_progress", "delivery_promotion", b"delivery_promotion", "desired_state_status_change", b"desired_state_status_change", "details", b"details", "key_delivery_decision", b"key_delivery_decision", "kubectl_cmd", b"kubectl_cmd", "manual_approval", b"manual_approval", "object_created", b"object_created", "object_deleted", b"object_deleted", "object_modified", b"object_modified", "permission_denied", b"permission_denied", "program_exit", b"program_exit", "rpc_call", b"rpc_call", "runtime_update", b"runtime_update", "set_desired_state", b"set_desired_state", "set_target_state", b"set_target_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["apply_target_state", b"apply_target_state", "audit_log_debug", b"audit_log_debug", "custom_task_execution", b"custom_task_execution", "delivery_progress", b"delivery_progress", "delivery_promotion", b"delivery_promotion", "desired_state_status_change", b"desired_state_status_change", "details", b"details", "key_delivery_decision", b"key_delivery_decision", "kubectl_cmd", b"kubectl_cmd", "manual_approval", b"manual_approval", "object_created", b"object_created", "object_deleted", b"object_deleted", "object_modified", b"object_modified", "permission_denied", b"permission_denied", "program_exit", b"program_exit", "rpc_call", b"rpc_call", "runtime_update", b"runtime_update", "set_desired_state", b"set_desired_state", "set_target_state", b"set_target_state"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["details", b"details"]) -> typing_extensions.Literal["set_desired_state", "set_target_state", "program_exit", "apply_target_state", "manual_approval", "custom_task_execution", "runtime_update", "delivery_progress", "delivery_promotion", "desired_state_status_change", "key_delivery_decision", "rpc_call", "permission_denied", "object_created", "object_deleted", "object_modified", "kubectl_cmd", "audit_log_debug"] | None: ...

global___EventDetails = EventDetails
